@@ -4,9 +4,7 @@ In-memory treq returns stubbed responses.
 from functools import partial
 from inspect import getmembers, isfunction
 
-from mock import ANY
-
-from six import text_type, binary_type, PY3
+from unittest.mock import ANY
 
 from twisted.trial.unittest import TestCase
 from twisted.web.client import ResponseFailed
@@ -54,6 +52,34 @@ class _EventuallyResponsiveTestResource(Resource):
         return NOT_DONE_YET
 
 
+class _SessionIdTestResource(Resource):
+    """
+    Resource that returns the current session ID.
+    """
+    isLeaf = True
+
+    def __init__(self):
+        super().__init__()
+        # keep track of all sessions created, so we can manually expire them later
+        self.sessions = []
+
+    def render(self, request):
+        session = request.getSession()
+        if session not in self.sessions:
+            # new session, add to internal list
+            self.sessions.append(session)
+        uid = session.uid
+        return uid
+
+    def expire_sessions(self):
+        """
+        Manually expire all sessions created by this resource.
+        """
+        for session in self.sessions:
+            session.expire()
+        self.sessions = []
+
+
 class StubbingTests(TestCase):
     """
     Tests for :class:`StubTreq`.
@@ -163,9 +189,9 @@ class StubbingTests(TestCase):
         self.successResultOf(stub.request('method', 'http://url', data=[]))
         self.successResultOf(stub.request('method', 'http://url', data=()))
         self.successResultOf(
-            stub.request('method', 'http://url', data=binary_type(b"")))
+            stub.request('method', 'http://url', data=b""))
         self.successResultOf(
-            stub.request('method', 'http://url', data=text_type("")))
+            stub.request('method', 'http://url', data=""))
 
     def test_handles_failing_asynchronous_requests(self):
         """
@@ -244,6 +270,40 @@ class StubbingTests(TestCase):
         stub.flush()
         self.successResultOf(d)
 
+    def test_session_persistence_between_requests(self):
+        """
+        Calling request.getSession() in the wrapped resource will return
+        a session with the same ID, until the sessions are cleaned.
+        """
+        rsrc = _SessionIdTestResource()
+        stub = StubTreq(rsrc)
+        # request 1, getting original session ID
+        d = stub.request("method", "http://example.com/")
+        resp = self.successResultOf(d)
+        cookies = resp.cookies()
+        sid_1 = self.successResultOf(resp.content())
+        # request 2, ensuring session ID stays the same
+        d = stub.request("method", "http://example.com/", cookies=cookies)
+        resp = self.successResultOf(d)
+        sid_2 = self.successResultOf(resp.content())
+        self.assertEqual(sid_1, sid_2)
+        # request 3, ensuring the session IDs are different after cleaning
+        # or expiring the sessions
+
+        # manually expire the sessions.
+        rsrc.expire_sessions()
+
+        d = stub.request("method", "http://example.com/")
+        resp = self.successResultOf(d)
+        cookies = resp.cookies()
+        sid_3 = self.successResultOf(resp.content())
+        self.assertNotEqual(sid_1, sid_3)
+        # request 4, ensuring that once again the session IDs are the same
+        d = stub.request("method", "http://example.com/", cookies=cookies)
+        resp = self.successResultOf(d)
+        sid_4 = self.successResultOf(resp.content())
+        self.assertEqual(sid_3, sid_4)
+
 
 class HasHeadersTests(TestCase):
     """
@@ -306,11 +366,10 @@ class HasHeadersTests(TestCase):
         """
         :obj:`HasHeaders` returns a nice string repr.
         """
-        if PY3:
-            reprOutput = "HasHeaders({b'a': [b'b']})"
-        else:
-            reprOutput = "HasHeaders({'a': ['b']})"
-        self.assertEqual(reprOutput, repr(HasHeaders({b'A': [b'b']})))
+        self.assertEqual(
+            "HasHeaders({b'a': [b'b']})",
+            repr(HasHeaders({b"A": [b"b"]})),
+        )
 
 
 class StringStubbingTests(TestCase):
